@@ -748,11 +748,13 @@ class StyleUpdator(object):
     """
     Updates style on a network in NDEx
     """
+
     COMMAND = 'styleupdate'
 
-    def __init__(self, theargs):
+    def __init__(self, theargs, altclient=None):
         """
         Constructor
+
         :param theargs: command line arguments ie theargs.name theargs.type
         """
         self._args = theargs
@@ -761,7 +763,7 @@ class StyleUpdator(object):
         self._pass = None
         self._server = None
         self._client = None
-
+        self._altclient = altclient
         self._count = None
         self._style = None
         self._old_to_new = None
@@ -772,6 +774,7 @@ class StyleUpdator(object):
         :py:const:`~ndexutil.config.NDExUtilConfig.USER`
         :py:const:`~ndexutil.config.NDExUtilConfig.PASSWORD`
         :py:const:`~ndexutil.config.NDExUtilConfig.SERVER`
+
         :return: None
         """
         ncon = NDExUtilConfig(conf_file=self._args.conf)
@@ -786,30 +789,87 @@ class StyleUpdator(object):
         :return: Ndex2 python client
         :rtype: :py:class:`~ndex2.client.Ndex2`
         """
+        if self._altclient is not None:
+            return self._altclient
         return Ndex2(self._server, self._user, self._pass)
 
     def _get_style_file(self, file):
+        """
+        Loads :py:class:`~ndex2.nice_cx_network.NiceCXNetwork`
+        from 'file'
+
+        :param file: Path to file containing CX network to load
+        :type file: str
+        :return: network loaded from 'file' passed in
+        :rtype: :py:class:`~ndex2.nice_cx_network.NiceCXNetwork`
+        """
         return ndex2.create_nice_cx_from_file(file)
 
     def _get_networks_from_networkset(self, uuid):
+        """
+        Gets networks from networkset with id 'uuid' from
+        server
+
+        :param uuid: NDEx networkset id
+        :type uuid: str
+        :return: NDEx UUIDs of networks belonging to networkset
+        :rtype: list
+        """
         info = self._client.get_networkset(uuid)
         return info['networks']
 
     def _get_network(self, uuid):
+        """
+        Gets network with NDEx UUID of 'uuid' from NDEx server
+
+        :param uuid: NDEx UUID identifying network
+        :type uuid: str
+        :return: Network
+        :rtype: :py:class:`~ndex2.nice_cx_network.NiceCXNetwork`
+        """
         return ndex2.create_nice_cx_from_server(
             self._server,
             username=self._user,
             password=self._pass,
-            uuid=uuid
-        )
+            uuid=uuid)
 
     def _get_network_visibility(self, uuid):
+        """
+        Gets visibility of network of network with NDEx UUID of 'uuid'
+        from server
+
+        :param uuid: NDEx UUID identifying network
+        :type uuid: str
+        :return:
+        """
         return self._client.get_network_summary(uuid)['visibility']
 
     def _get_network_and_visibility(self, uuid):
+        """
+        Gets a tuple containing network and its visibility for
+        network with NDEx UUID of 'uuid'
+
+        :param uuid: NDEx UUID identifying network
+        :type uuid: str
+        :return: (network, network visibility)
+        :rtype: tuple (:py:class:`~ndex2.nice_cx_network.NiceCXNetwork`, str)
+        """
         return self._get_network(uuid), self._get_network_visibility(uuid)
     
     def _create_new_network(self, old_uuid, network, visibility):
+        """
+        Adds 'network' as a new network on NDEx with visibility
+        set via the 'visibility' flag. Method also updates
+        self._old_to_new dict setting key to old UUID of network and
+        value set to UUID of newly created network
+
+        :param old_uuid: NDEx UUID of old/original network
+        :type old_uuid: str
+        :param network:
+        :type network: :py:class:`~ndex2.nice_cx_network.NiceCXNetwork`
+        :param visibility: visibility of network on NDEx
+        :type visibility: str
+        """
         uri = self._client.save_new_network(network.to_cx(), visibility)
         new_uuid = self._get_id_from_uri(uri)
         self._old_to_new[old_uuid] = new_uuid
@@ -822,12 +882,10 @@ class StyleUpdator(object):
 
     def _apply_style_from_uuid_to_new_network(self, uuid):
         network, visibility = self._get_network_and_visibility(uuid)
-        network.apply_template(
-            server=self._server,
-            username=self._user,
-            password=self._pass,
-            uuid=uuid
-        )
+        network.apply_template(server=self._server,
+                               username=self._user,
+                               password=self._pass,
+                               uuid=self._args.styleuuid)
         self._create_new_network(uuid, network, visibility)
         self._count += 1
 
@@ -839,12 +897,10 @@ class StyleUpdator(object):
 
     def _apply_style_from_uuid_to_original_network(self, uuid):
         network = self._get_network(uuid)
-        network.apply_template(
-            server=self._server,
-            username=self._user,
-            password=self._pass,
-            uuid=uuid
-        )
+        network.apply_template(server=self._server,
+                               username=self._user,
+                               password=self._pass,
+                               uuid=self._args.styleuuid)
         self._client.update_cx_network(network.to_cx_stream(), uuid)
         self._count += 1
 
@@ -852,46 +908,85 @@ class StyleUpdator(object):
         return uri.split('/')[-1]
 
     def _copy_networkset(self, networkset_uuid):
-        # Make new network set
+        """
+        Creates a new networkset and adds in all new
+        networks into that set. The new network set is
+        named Copy of <ORIGINAL NETWORKSET NAME>
+
+        If the there is an error creating the copy of the
+        network set, the operation is attempted again
+        where the networkset name is set to
+        Copy of <ORIGINAL NETWORKSET NAME> (COPY NUMBER STARTING AT 1)
+
+        Example if original network set is foo:
+
+        If successful on first try network set will be named:
+        Copy of foo
+
+        If failure on first try, but second works network set will
+        be named:
+        Copy of foo (1)
+
+        :param networkset_uuid: NDEx UUID identifying networkset to copy
+        :type networkset_uuid: str
+        :return: id of new networkset
+        :rtype: str
+        """
+
         info = self._client.get_networkset(networkset_uuid)
         name = info['name']
         description = info['description']
 
         # Make sure network set name is unique
         copy_number = 0
-        done = False
-        while not done:
+        while copy_number < self._args.networksetretry:
             try:
                 if copy_number == 0:
                     copy_string = ''
                 else:
                     copy_string = ' (' + str(copy_number) + ')'
-                uri = self._client.create_networkset(
-                    'Copy of ' + name + copy_string, 
-                    description)
-                done = True
+                netset_name = 'Copy of ' + name + copy_string
+                uri = self._client.create_networkset(netset_name,
+                                                     description)
+                # Copy put new networks in new network set
+                networkset_id = self._get_id_from_uri(uri)
+                networks = list(self._old_to_new.values())
+                self._client.add_networks_to_networkset(networkset_id,
+                                                        networks)
+                return networkset_id
             except HTTPError as e:
-                copy_number += 1
+                logger.warning('Attempting to create'
+                               'network set named ' +
+                               netset_name +
+                               ' failed, possibly due to ' +
+                               'duplicate name : ' + str(e))
+            copy_number += 1
 
-        # Copy put new networks in new network set
-        networkset_id = self._get_id_from_uri(uri)
-        networks = list(self._old_to_new.values())
-        self._client.add_networks_to_networkset(networkset_id, networks)
-        
-        return networkset_id
+        raise NDExUtilError('After ' + str(self._args.networksetretry) +
+                            ' attempts unable to create a network set with ' +
+                            ' name of Copy of ' + name + ' (#)')
 
     def _get_new_uuid_string(self, old_uuid, new_uuid):
+        """
+        Creates string reporting what network was copied to what
+
+        :param old_uuid: NDEx UUID identifying a network
+        :type old_uuid: str
+        :param new_uuid: NDEx UUID identifying a network
+        :type new_uuid: str
+        :return: Message about what network was copied
+        :rtype: str
+        """
         return ('Network with uuid {old_uuid} was copied to network with '
-               'uuid {new_uuid}').format(
-                   old_uuid=old_uuid, 
-                   new_uuid=new_uuid)
+                'uuid {new_uuid}').format(old_uuid=old_uuid,
+                                          new_uuid=new_uuid)
 
     def _print_new_networkset_uuids(self, old_networkset_id, new_networkset_id):
         old_name = self._client.get_networkset(old_networkset_id)['name']
         new_name = self._client.get_networkset(new_networkset_id)['name']
         print_string = ('\nNetworks in old networkset "{old_name}" ({old_uuid}) '
-                       'have been copied to new networkset "{new_name}" '
-                       '({new_uuid}) with new style:').format(
+                        'have been copied to new networkset "{new_name}" '
+                        '({new_uuid}) with new style:').format(
                            old_name=old_name, 
                            old_uuid=old_networkset_id,
                            new_name=new_name,
@@ -901,16 +996,77 @@ class StyleUpdator(object):
                                         old_network, new_network)
         print(print_string + '\n')
 
+    def _get_style_function_to_use(self):
+        """
+
+        :return:
+        """
+        if self._args.stylefile:
+            self._style = self._get_style_file(self._args.stylefile)
+            if self._args.newcopy:
+                return self._apply_style_from_file_to_new_network
+            else:
+                return self._apply_style_from_file_to_original_network
+        if self._args.newcopy:
+            return self._apply_style_from_uuid_to_new_network
+        else:
+            return self._apply_style_from_uuid_to_original_network
+
+    def _update_networkset_style(self,
+                                 style_function=None):
+        """
+        Updates style on networks in network set with id
+        `self._args.networkset` using `style_function` passed in.
+        If `self._args.newcopy` is True then new networks are uploaded
+        along with networkset otherwise update occurs in place
+
+        :param style_function: function that takes NDEx networkset UUID
+                               to apply styles to networks
+        :type style_function: python function
+        :return: 0 for success
+        :rtype: int
+        """
+        uuids = self._get_networks_from_networkset(self._args.networkset)
+        for uuid in uuids:
+            style_function(uuid)
+        if self._args.newcopy:
+            # Make new networkset
+            networkset_uuid = self._copy_networkset(self._args.networkset)
+            # Print new uuids
+            self._print_new_networkset_uuids(
+                self._args.networkset,
+                networkset_uuid)
+        return 0
+
+    def _update_network_style(self, style_function=None):
+        """
+        Updates style of network with id `self._args.uuid`
+        via `style_function`. If `self._args.newcopy` is True then
+        a new network is uploaded otherwise update occurs in place
+
+        :param style_function:
+        :return:
+        """
+        style_function(self._args.uuid)
+        if self._args.newcopy:
+            print('\n' + self._get_new_uuid_string(
+                self._args.uuid,
+                self._old_to_new[self._args.uuid]) + '\n')
+        return 0
+
     def run(self):
         """
-        Connects to NDEx server, downloads network(s) specified by --uuid
-        or by --networkset and applies style specified by --style flag
-        updating those networks in place on the server.
+        Connects to NDEx server, downloads network(s) specified by
+        --uuid or by --networkset and applies style specified by
+        --styleuuid or --stylefile flag
+        updating those networks in place on the server unless --newcopy
+        flag is set in which case new networks and networkset is created
         WARNING: This is very inefficient method since the full network
                  is downloaded and uploaded. YOU HAVE BEEN WARNED.
 
         :raises NDExUtilError if there is an error
-        :return: number of networks updated
+        :return: 0 upon success
+        :rtype: int
         """
         logger.warning('THIS IS AN UNTESTED ALPHA IMPLEMENTATION '
                        'AND MAY CONTAIN ERRORS')
@@ -918,55 +1074,24 @@ class StyleUpdator(object):
         self._parse_config()
         self._client = self._get_client()
 
-        # Check arguments
-        if self._args.stylefile is None and self._args.styleuuid is None:
-            raise NDExUtilError('Either --stylefile or --styleuuid must be '
-                                'specified')
-        if self._args.stylefile is not None and self._args.styleuuid is not None:
-            raise NDExUtilError('Only one of --stylefile or --styleuuid may be'
-                                'specified')
-
         # Set up counter
         self._count = 0
 
+        # setup dict for mapping of old network to
+        # new network
+        if self._args.newcopy:
+            self._old_to_new = {}
+
         # Find function to use
-        if self._args.stylefile:
-            self._style = self._get_style_file(self._args.stylefile)
-            if self._args.newcopy:
-                self._old_to_new = {}
-                style_function = self._apply_style_from_file_to_new_network
-            else:
-                style_function = self._apply_style_from_file_to_original_network
-        else:
-            if self._args.newcopy:
-                self._old_to_new = {}
-                style_function = self._apply_style_from_uuid_to_new_network
-            else:
-                style_function = self._apply_style_from_uuid_to_original_network
+        style_function = self._get_style_function_to_use()
 
-        # Apply style
+        # Apply style to networkset networks
         if self._args.networkset is not None:
-            uuids = self._get_networks_from_networkset(self._args.networkset)
-            for uuid in uuids:
-                style_function(uuid)
-            if self._args.newcopy:
-                # Make new networkset
-                networkset_uuid = self._copy_networkset(self._args.networkset)
-                # Print new uuids
-                self._print_new_networkset_uuids(
-                    self._args.networkset,
-                    networkset_uuid
-                )
+            return self._update_networkset_style(style_function=style_function)
+
+        # Apply style to single network
+        return self._update_network_style(style_function=style_function)
 
-        if self._args.uuid is not None:
-            style_function(self._args.uuid)
-            if self._args.newcopy:
-                print('\n' + self._get_new_uuid_string(
-                    self._args.uuid, 
-                    self._old_to_new[self._args.uuid]) + '\n')
-        
-        return 0
-        
     @staticmethod
     def add_subparser(subparsers):
         """
@@ -979,9 +1104,24 @@ class StyleUpdator(object):
         Version {version}
 
         The {cmd} command updates the style of a network or networks specified 
-        by --uuid or --networkset with the style specified by --style (this can 
-        be a file or a uuid)
+        by --uuid or --networkset with the style specified by --styleuuid or
+        --stylefile flags.
+        
+        NOTE: Either --uuid or --networkset must be specified and either
+              --styleuuid or --stylefile must be specified.
 
+        If --newcopy flag is set then new networks will be uploaded with
+        same name. If --networkset is also specified, a new network set will
+        be created and named Copy of <ORIG NAME> and if that exists then
+        (#) will be appended to name starting at 1. 
+        
+        For example, if networkset is named foo and Copy of foo exists then
+        the new networkset will be named Copy of foo (1). If Copy of foo (1)
+        is taken then Copy of foo (2) will be created. This goes on until
+        the value in (#) reaches value of --networksetretry which is set
+        to a default of 50. 
+        
+        
         WARNING: THIS IS AN UNTESTED ALPHA IMPLEMENTATION AND MAY CONTAIN
                  ERRORS. YOU HAVE BEEN WARNED.
 
@@ -992,29 +1132,43 @@ class StyleUpdator(object):
                                        help='Updates style of network on NDEx',
                                        description=desc,
                                        formatter_class=Formatter)
-
-        parser.add_argument('--uuid',
-                            default=None,
-                            help='The UUID of the network in NDEx to apply the '
-                                 'new style to')
-        parser.add_argument('--networkset',
-                            default=None,
-                            help='The UUID of the network set in NDEx to apply '
-                                 'the new style to')
-        parser.add_argument('--styleuuid',
-                            default=None,
-                            help='The UUID of the network whose style should '
-                            'be applied to the other networks')
-        parser.add_argument('--stylefile',
-                            default=None,
-                            help='The path to a cx file whose style should be '
-                            'applied to the other networks')
+        src_grp = parser.add_mutually_exclusive_group(required=True)
+        src_grp.add_argument('--uuid', default=None,
+                             help='The UUID of the network in NDEx to '
+                                  'apply the new style to. Either this '
+                                  'flag or --networkset must be specified '
+                                  'on the commandline')
+        src_grp.add_argument('--networkset', default=None,
+                             help='The UUID of the network set in NDEx to '
+                                  'apply the new style to. Either this '
+                                  'flag or --uuid must be specified on the '
+                                  'commandline')
+        style_src_grp = parser.add_mutually_exclusive_group(required=True)
+        style_src_grp.add_argument('--styleuuid',
+                                   default=None,
+                                   help='The UUID of the network whose '
+                                        'style should be applied to the '
+                                        'other networks. Either this flag '
+                                        'or --stylefile must be specified '
+                                        'on the commandline')
+        style_src_grp.add_argument('--stylefile',
+                                   default=None,
+                                   help='The path to a cx file whose '
+                                        'style should be applied to '
+                                        'the other networks. Either this '
+                                        'flag or --styleuuid must be '
+                                        'specified on the commandline')
         parser.add_argument('--newcopy',
                             default=False,
                             action='store_true',
                             help='If set, a new copy of each network or '
                             'network set will be made, and the original '
                             'or network set will not be changed')
+        parser.add_argument('--networksetretry', default=50, type=int,
+                            help='Maximum number of retries before failing '
+                                 'to make a copy of a network set. The'
+                                 'failure is usually due to a networkset'
+                                 'with an identical name')
         return parser
 
 
