@@ -1,28 +1,123 @@
 
-import ndex2 # The ndex2 Python client
-import ndex2.client as nc
-import csv
-import sys
-import os
-sys.path.insert(0, os.path.abspath('../../../ndex2_performance/ndex2-client'))
-
 import json
+import os
 from os import path
-from jsonschema import validate
+import jsonschema
 import pandas as pd
-#import ndex2
-from ndex2cx.NiceCXBuilder import NiceCXBuilder
 import time
 import re
-import numpy as np
-import types
-import six
-import gspread
+import logging
+from ndex2cx.nice_cx_builder import NiceCXBuilder
+from ndex2.client import Ndex2
 
 version="0.1"
 
 node_id_lookup = {}
 
+logger = logging.getLogger(__name__)
+
+
+class ContentImporter(object):
+    def __init__(self, server, username, password, **attr):
+        self.update_mapping = {}
+        self.server = server
+        self.username = username
+        self.password = password
+        self.network = None
+        self.ndex = Ndex2(self.server, self.username, self.password)
+
+        networks = self.ndex.get_network_summaries_for_user(self.username)
+        for nk in networks:
+            if nk.get('name') is not None:
+                self.update_mapping[nk.get('name').upper()] = nk.get('externalId')
+
+    def process_file(self, file_name, load_plan_path, name, style_template=None, custom_header=None, delimiter='\t'):
+        # ==============================
+        # LOAD TSV FILE INTO DATAFRAME
+        # ==============================
+        if not os.path.isfile(file_name): # If file is not in main directory try the ./data directory
+            file_name = os.path.join('data', file_name)
+
+        if not os.path.isfile(load_plan_path): # If file is not in main directory try the ./data directory
+            load_plan_path = os.path.join('data', load_plan_path)
+
+        with open(file_name, 'r', encoding='utf-8', errors='ignore') as tsvfile:
+            if custom_header is None:
+                header = [h.strip() for h in tsvfile.readline().split(delimiter)]
+
+                df = pd.read_csv(tsvfile, delimiter=delimiter, na_filter=False, engine='python', names=header,
+                                 dtype=str, error_bad_lines=False, comment='#')
+            else:
+                if isinstance(custom_header, list):
+                    df = pd.read_csv(tsvfile, delimiter=delimiter, na_filter=False, engine='python', names=custom_header,
+                                     dtype=str, error_bad_lines=False, comment='#')
+                else:
+                    raise Exception('Custom header provided was not of type list')
+
+        # =====================
+        # LOAD TSV LOAD PLAN
+        # =====================
+        if load_plan_path is not None:
+            try:
+                with open(load_plan_path, 'r') as lp:
+                    load_plan = json.load(lp)
+            except jsonschema.ValidationError as e1:
+                logger.exception("Failed to parse the loading plan: " + e1.message)
+                logger.error('at path: ' + str(e1.absolute_path))
+                logger.error("in block: ")
+                logger(e1.instance)
+        else:
+            raise Exception('Please provide a load plan')
+
+        # ====================
+        # UPPERCASE COLUMNS
+        # ====================
+        rename = {}
+        for column_name in df.columns:
+            rename[column_name] = column_name.upper()
+
+        network = convert_pandas_to_nice_cx_with_load_plan(df, load_plan)
+        network.set_name(name)
+        if style_template is not None:
+            logger.debug('Applying style from network: ' + style_template)
+            network.apply_template(username=self.username, password=self.password, server=self.server,
+                               uuid=style_template)
+
+        self.network = network
+
+    def upload_network(self, re_use_metadata=True):
+        network_update_key = self.update_mapping.get(self.network.get_name().upper())
+        if network_update_key is not None and re_use_metadata in ['true', 'True', 'yes', True]:
+            logger.debug("Updating")
+            self.update_network_properties(network_update_key)
+            message = self.network.update_to(network_update_key, self.server, self.username, self.password)
+        else:
+            logger.debug("New network")
+            message = self.network.upload_to(self.server, self.username, self.password)
+
+        logger.info(message)
+
+    def get_network_properties(self, uuid):
+
+        network_properties_stream = self.ndex.get_network_aspect_as_cx_stream(uuid, 'networkAttributes')
+
+        network_properties = network_properties_stream.json()
+        return_properties = {}
+        for net_prop in network_properties:
+            return_properties[net_prop.get('n')] = net_prop.get('v')
+
+        return return_properties
+
+    def update_network_properties(self, uuid):
+        network_properties = self.get_network_properties(uuid)
+
+        for k, v in network_properties.items():
+            self.network.set_network_attribute(k, v)
+
+    def print_summary(self):
+        print('Loading...')
+
+
 #=====================
 # NON-CLASS FUNCTIONS
 #=====================
@@ -35,16 +130,19 @@ def convert_pandas_to_nice_cx_with_load_plan(pandas_dataframe, load_plan, max_ro
     with open(path.join(here, 'loading_plan_schema.json')) as json_file:
         plan_schema = json.load(json_file)
 
-    validate(load_plan, plan_schema)
+    jsonschema.validate(load_plan, plan_schema)
 
     node_lookup = {}
     nice_cx_builder = NiceCXBuilder()
     row_count = 0
     t1 = int(time.time()*1000)
+
     #Add context if they are defined
-    if load_plan.get('context'):
-        nice_cx_builder.set_context(load_plan.get('context'))
-        #self.ng_builder.addNamespaces(self.plan.context)
+    context = load_plan.get('context')
+    if context:
+        if network_attributes is None:
+            network_attributes = []
+        network_attributes.append({"n": "@context", "v": json.dumps(context)})
 
     total_row_count = pandas_dataframe.shape
     if len(total_row_count) > 1:
@@ -57,7 +155,7 @@ def convert_pandas_to_nice_cx_with_load_plan(pandas_dataframe, load_plan, max_ro
             break
 
         if row_count % 2500 == 0:
-            print('processing %s out of %s edges' % (str(row_count), total_row_count))
+            logger.info('processing %s out of %s edges' % (str(row_count), total_row_count))
 
     if network_attributes:
         for attribute in network_attributes:
@@ -82,10 +180,11 @@ def convert_pandas_to_nice_cx_with_load_plan(pandas_dataframe, load_plan, max_ro
     if name:
         nice_cx_builder.set_name(name)
     if description:
-        nice_cx_builder.set_network_attribute(name='description', values=description)
+        nice_cx_builder.add_network_attribute(name='description', values=description)
 
     return nice_cx_builder.get_nice_cx()
 
+
 #==================================
 # Process Row USING NiceCX
 # Added by Aaron G
@@ -98,12 +197,14 @@ def process_row(nice_cx_builder, load_plan, row, node_lookup):
     # - predicate term
     skipped_edge = False
 
+    logger.debug(row)
     source_node = create_node(row, load_plan.get('source_plan'), nice_cx_builder, node_lookup)
     target_node = create_node(row, load_plan.get('target_plan'), nice_cx_builder, node_lookup)
 
     if source_node is not None and target_node is not None:
         create_edge(nice_cx_builder, source_node, target_node, row, load_plan)
 
+
 def create_node(row, node_plan, nice_cx_builder, node_lookup):
     use_name_as_id = False
     node_name_column = node_plan['node_name_column']
@@ -163,7 +264,6 @@ def create_edge(nice_cx_builder, src_node_id, tgt_node_id, row, import_plan):
 
     if not predicate_str:
         raise RuntimeError("Value for predicate string is not found in this row.")
-
     if edge_plan.get("predicate_prefix"):
         predicate_str = edge_plan['predicate_prefix'] + ":" + predicate_str
 
@@ -205,6 +305,7 @@ valid_cx_data_types = ['boolean', 'byte', 'char', 'double', 'float', 'integer',
  'list_of_byte', 'list_of_char', 'list_of_double', 'list_of_float', 'list_of_integer', 'list_of_long',
  'list_of_short','list_of_string']
 
+
 def add_node_attributes(nice_cx_builder, node_element, load_plan, row):
     if load_plan.get('property_columns'):
         for column_raw_temp in load_plan['property_columns']:
@@ -245,7 +346,7 @@ def add_node_attributes(nice_cx_builder, node_element, load_plan, row):
                         if column_raw['data_type'] not in valid_cx_data_types:
                             raise Exception('data_type: ' + column_raw['data_type'] + ' is not valid')
                         value = value.split(column_raw.get('delimiter'))
-
+                        value = [entry.strip() for entry in value]
                         value = data_to_type(value, column_raw['data_type'])
                         if not type_temp.startswith('list'):
                             type_temp = 'list_of_' + type_temp
@@ -253,6 +354,7 @@ def add_node_attributes(nice_cx_builder, node_element, load_plan, row):
                         if not isinstance(value, str):
                             value = str(value)
                         value = value.split(column_raw.get('delimiter'))
+                        value = [entry.strip() for entry in value]
                         type_temp = 'list_of_string'
 
                     if column_raw.get('value_prefix'):
@@ -278,6 +380,7 @@ def add_node_attributes(nice_cx_builder, node_element, load_plan, row):
                 else:
                     nice_cx_builder.add_node_attribute(node_element, column_raw['column_name'], value, type=type_temp)
 
+
 def add_edge_attributes(nice_cx_builder, edge_id, load_plan, row):
     if load_plan.get('property_columns'):
         for column_raw_temp in load_plan['property_columns']:
@@ -316,7 +419,7 @@ def add_edge_attributes(nice_cx_builder, edge_id, load_plan, row):
                 else:
                     continue
 
-            if value:
+            if value is not None:
                 dt = None
 
                 if column_raw.get('delimiter'):
@@ -326,11 +429,13 @@ def add_edge_attributes(nice_cx_builder, edge_id, load_plan, row):
                             raise Exception('data_type: ' + dt + ' is not valid')
 
                         value = value.split(column_raw.get('delimiter'))
+                        value = [entry.strip() for entry in value]
                         value = data_to_type(value, dt)
                         if not type_temp.startswith('list'):
                             type_temp = 'list_of_' + type_temp
                     else:
                         value = value.split(column_raw.get('delimiter'))
+                        value = [entry.strip() for entry in value]
                         type_temp = 'list_of_string'
 
                     if column_raw.get('value_prefix'):
@@ -350,6 +455,15 @@ def add_edge_attributes(nice_cx_builder, edge_id, load_plan, row):
                     if column_raw.get('value_prefix'):
                         value = column_raw.get('value_prefix') + ":" + str(value)
 
+                if value is None:
+                    logger.debug('Value is None, skipping edge attribute'
+                                 'edge id => ' + str(edge_id) +
+                                 ' name => ' + str(column_raw) +
+                                 ' values => ' + str(value) +
+                                 ' type => ' + str(type_temp))
+
+                    continue
+
                 if column_raw.get('attribute_name'):
                     nice_cx_builder.add_edge_attribute(property_of=edge_id, name=column_raw['attribute_name'],
                                                        values=value, type=type_temp)
@@ -416,45 +530,6 @@ def data_to_type(data, data_type):
 
     return return_data
 
-'''
-def create_edge(src_node_id, tgt_node_id, row, plan, nice_cx):
-
-    predicate_str = None
-    if  plan.edge_plan.get('predicate_id_column'):
-        predicate_str = row.get(plan.edge_plan['predicate_id_column'])
-
-    if not predicate_str and plan.edge_plan.get('default_predicate'):
-        predicate_str = plan.edge_plan['default_predicate']
-
-    if not predicate_str :
-        raise RuntimeError("Value for predicate string is not found this row.")
-
-    if plan.edge_plan.get("predicate_prefix"):
-        predicate_str = plan.edge_plan['predicate_prefix']+ ":"+ predicate_str
-
-    edge_attr = create_attr_obj(plan.edge_plan, row)
-
-    #Deal with citiations
-    citation_id = None
-    if  self.plan.edge_plan.get("citation_id_column"):
-        citation_id = row.get(self.plan.edge_plan['citation_id_column'])
-
-    if citation_id is not None:
-        citation_id = citation_id.replace(';', ',')
-        citation_id = citation_id.replace('|', ',')
-        citation_id = re.split('\s*,\s*',citation_id)
-
-    if citation_id and plan.edge_plan.get("citation_id_prefix"):
-            newList = []
-            for cid in citation_id:
-                newList.append(plan.edge_plan["citation_id_prefix"] + ":" + cid)
-            citation_id = newList
-
-    if citation_id :
-        edge_attr['citation_ids'] = citation_id
-
-    ng_builder.addEdge(src_node_id,tgt_node_id,predicate_str, edge_attr)
-'''
 
 def find_or_create_node(nice_cx, name, represents, node_lookup):
     if node_lookup.get(represents):
